Learning how to use the agents
==============================

.. toctree::
   :maxdepth: 3

   agentMET4FOF_tutorials/tutorial_1_generator_agent.ipynb
   agentMET4FOF_tutorials/tutorial_2_math_agent.ipynb
   agentMET4FOF_tutorials/tutorial_3_multi_channel.ipynb
   agentMET4FOF_tutorials/tutorial_4_metrological_streams.ipynb
   agentMET4FOF_tutorials/tutorial_5_coalition.ipynb
   agentMET4FOF_tutorials/tutorial_6_mesa_backend.ipynb
   agentMET4FOF_tutorials/tutorial_7_generic_metrological_agent.ipynb

.. _redundancy_tutorials:

Working with signals carrying redundant information
===================================================

.. toctree::
   :maxdepth: 3

   agentMET4FOF_tutorials/redundancy/redundancy_agent_four_signals.ipynb
   agentMET4FOF_tutorials/redundancy/redundancy_agent_one_signal.ipynb